@@ -2,18 +2,19 @@ from __future__ import absolute_import
 import errno
 import select
 import logging
-from contextlib import contextmanager
 
 import pika
 import pika.exceptions
 
 from kuyruk import exceptions
 from kuyruk.task import Task
+from kuyruk.queue import Queue
 from kuyruk.config import Config
-from kuyruk.events import EventMixin
 from kuyruk.worker import Worker
+from kuyruk.events import EventMixin
+from kuyruk.connection import Connection
 
-__version__ = '0.18.0'
+__version__ = '0.19.0'
 
 try:
     # not available in python 2.6
@@ -41,7 +42,6 @@ def ready(self):
     while True:
         try:
             return original_method(self)
-            break
         except select.error as e:
             if e[0] != errno.EINTR:
                 raise
@@ -65,6 +65,7 @@ class Kuyruk(EventMixin):
         self.task_class = task_class
         self.config = Config()
         self._connection = None
+        self._channel = None
         if config:
             self.config.from_object(config)
 
@@ -109,13 +110,33 @@ class Kuyruk(EventMixin):
             logger.debug('task with args')
             return decorator()
 
-    @property
     def connection(self):
-        """Persistent connection object of instance."""
-        if self._connection is None:
+        """
+        Returns the shared RabbitMQ connection.
+        Creates a new connection if it is not connected.
+
+        """
+        if self._connection is None or not self._connection.is_open:
             self._connection = self._connect()
+
         return self._connection
 
+    def channel(self):
+        """
+        Returns the shared channel.
+        Creates a new channel if there is no available.
+
+        """
+        if self._channel is None or not self._channel.is_open:
+            self._channel = self._open_channel()
+
+        return self._channel
+
+    def close(self):
+        if self._connection is not None:
+            if self._connection.is_open:
+                self._connection.close()
+
     def _connect(self):
         """Returns new connection object."""
         parameters = pika.ConnectionParameters(
@@ -125,42 +146,28 @@ class Kuyruk(EventMixin):
             credentials=pika.PlainCredentials(
                 self.config.RABBIT_USER,
                 self.config.RABBIT_PASSWORD),
-            heartbeat_interval=600,
+            heartbeat_interval=0,  # We don't want heartbeats
             socket_timeout=2,
             connection_attempts=2)
-        connection = pika.BlockingConnection(parameters)
+        connection = Connection(parameters)
         logger.info('Connected to RabbitMQ')
         return connection
 
-    def _channel(self):
-        """Returns new channel object."""
+    def _open_channel(self):
+        """Returns a new channel."""
         CLOSED = (pika.exceptions.ConnectionClosed,
                   pika.exceptions.ChannelClosed)
 
         try:
-            return self.connection.channel()
+            channel = self.connection().channel()
         except CLOSED:
             logger.warning("Connection is closed. Reconnecting...")
             try:
                 self._connection.close()
             except CLOSED:
-                logger.debug("Connection is already closed.")
+                pass
 
             self._connection = self._connect()
-            return self._connection.channel()
+            channel = self._connection.channel()
 
-    @contextmanager
-    def channel(self):
-        """
-        Yields a new channel object.
-        When exiting the context the channel will be closed.
-
-        """
-        ch = self._channel()
-        try:
-            yield ch
-        finally:
-            try:
-                ch.close()
-            except pika.exceptions.ChannelClosed:
-                logger.debug("Channel is already closed.")
+        return channel
