@@ -9,6 +9,9 @@ from kuyruk import Task
 from kuyruk.task import TaskResult, BoundTask
 from kuyruk.test import tasks
 from kuyruk.test.util import *
+from kuyruk.connection import Channel
+
+Channel.SKIP_REDECLARE_QUEUE = False
 
 logger = logging.getLogger(__name__)
 
