@@ -9,7 +9,9 @@ import multiprocessing
 from time import time, sleep
 from datetime import datetime
 from functools import wraps
+
 from setproctitle import setproctitle
+
 import kuyruk
 from kuyruk import importer
 from kuyruk.queue import Queue
@@ -58,7 +60,7 @@ class Worker(KuyrukProcess):
     """
     def __init__(self, kuyruk, queue_name):
         super(Worker, self).__init__(kuyruk)
-        self.channel = self.kuyruk._channel()
+        self.channel = self.kuyruk.channel()
         is_local = queue_name.startswith('@')
         queue_name = queue_name.lstrip('@')
         self.queue = Queue(queue_name, self.channel, local=is_local)
